@@ -1,18 +1,20 @@
-import "assets/img/bg-51.jpg";
-import "assets/img/bg-52.jpg";
 import Vue from "vue";
+import components from '../components/welcome';
 
-Vue.config.debug = true;
-var {mapGetters, mapActions, Store} = Vuex;
+let codex =  window.codex;
 
+Object.keys(components).forEach(key => Vue.component(key, components[key]));
 
-const wow = new WOW();
+const wow = new WOW({
+    mobile: false,
+});
 wow.init();
 
+var {mapGetters, mapActions, Store} = Vuex;
 const store = new Store({});
-Vue.use(CodexPlugin, {
-    store
-});
+Vue.use(codex.CodexPlugin, { store });
+
+Vue.codex.extend({ wow, store })
 
 const App = Vue.extend({
     store,
@@ -30,6 +32,7 @@ const App = Vue.extend({
         });
 
         this.$$ready(() => {
+            this.$nextTick(() => codex.loader.stop())
             let $header = $(this.$refs.header.$el);
             this.$$('.scrollspy').scrollSpy({
                 scrollOffset: $header.outerHeight(true) + 1
@@ -43,6 +46,4 @@ const App = Vue.extend({
     }
 });
 
-window['codex'] = {store, App};
-
-console.log('sc');
+codex.App = App;
